API docs for “spamfighter.core.commands.serialize.ISerializable”

# Class s.c.c.s.ISerializable(Interface):

Part of spamfighter.core.commands.serialize View Source View In Hierarchy

Known subclasses: spamfighter.core.commands.partner.IPartnerAuthInfo, spamfighter.core.commands.test.test_command.IFakeSerializable, spamfighter.core.commands.test.test_serialize.ISerializableInterface, spamfighter.core.message.serialize.ITransitMessage

Сущность, которая может передаваться в команде (и, соответственно, должна уметь превращаться в часть параметров или результатов) и умеет "вылезать" из неё.

Method | serialize | Получить сериализованное представление элемента.
Method | unserialize | Восстановить экземпляр объекта из его сериализованного представления

def serialize(): (source)
Получить сериализованное представление элемента.

Returns | сериализованное представление, Deferred (`str`) (type: `twisted.internet.defer.Deferred` )

def unserialize(serialized): (source)
Восстановить экземпляр объекта из его сериализованного представления

Parameters | serialized | сериализованное представление объекта
Returns | восстановленный экземпляр объекта